package resellerapi

// BillingPeriod represents a billing period for recurring (leased) licenses
type BillingPeriod int

const (
	// NonRecurring specifies that the license is not leased/recurring
	NonRecurring BillingPeriod = iota
	// MonthlyBilling specifies a monthly billing period
	MonthlyBilling
	// QuarterlyBilling specifies a quarterly billing period
	QuarterlyBilling
	// BiannualBilling specifies a biannual billing period
	BiannualBilling
	// AnnualBilling specifies an annual billing period
	AnnualBilling
)

// billingPeriods specifies the raw API values for each billing period
var billingPeriods = map[BillingPeriod]string{
	NonRecurring:     "",
	MonthlyBilling:   "monthly",
	QuarterlyBilling: "quarterly",
	BiannualBilling:  "biannually",
	AnnualBilling:    "annually",
}

