//
// Centova Reseller API - https://centova.com
// Copyright 2021, Centova Technologies Inc.
//
// This library is a Go implementation of a Centova Technologies Reseller API client.
//

package resellerapi

import (
	"encoding/json"
)

// APIResponse represents a response from the reseller API.
type APIResponse struct {
	// the result of the API request (`success` or `error`)
	Result string `json:"result"`
	// the HTTP status code for the response
	Code int `json:"code"`
	// the message returned with the response
	Message string `json:"message"`
	// the raw bytes of the response payload
	Data json.RawMessage `json:"data"`
}

// Successful indicates whether the request was successful.
func (a APIResponse) Successful() bool {
	return a.Result == "success"
}

// UnmarshalData is a helper function to decode JSON data in Data to the target variable.
func (a APIResponse) UnmarshalData(target interface{}) error {
	return json.Unmarshal(a.Data,target)
}

