//
// Centova Reseller API - https://centova.com
// Copyright 2021, Centova Technologies Inc.
//
// This library is a Go implementation of a Centova Technologies Reseller API client.
//

package response

// License represents a license in a reseller's account
type License struct {
	// license ID number
	ID int `json:"license_id"`
	// client email address
	ClientEmail string `json:"client_email"`
	// IDENT passed when creating the license
	Identifier string `json:"identifier"`
	// package ID (see "list packages")
	PackageID int `json:"package_id"`
	// package name
	PackageName string `json:"package_name"`
	// license status
	Status string `json:"status"`
	// human-friendly license name
	DisplayName string `json:"display_name"`
	// date order was created
	CreationDate string `json:"creation_date"`
	// billing period, if leased
	BillingPeriod string `json:"billing_period"`
	// recurring billing amount, if leased
	BillingAmount CurrencyInCents `json:"billing_amount"`
	// next billing date, if leased
	BillingNext string `json:"billing_next"`
	// product license key
	LicenseKey string `json:"license_key"`
	// license issued domain name
	LicensedDomain string `json:"licensed_domain"`
	// license issued IP address
	LicensedIP string `json:"licensed_ip"`
	// license issued MAC address
	LicensedMAC string `json:"licensed_mac"`
	// license issued path
	LicensedPath string `json:"licensed_path"`
	// true if issued, otherwise false
	Issued BoolInt `json:"issued"`
	// date on which license was issued
	IssueDate string `json:"issue_date"`
	// expiration date for the license
	Expiration string `json:"expiration"`
}

// LicenseList represents an API response from the `licenselist` API call.
type LicenseList struct {
	// the licenses in the reseller account
	Licenses []License `json:"licenses"`
}
