//
// Centova Reseller API - https://centova.com
// Copyright 2021, Centova Technologies Inc.
//
// This library is a Go implementation of a Centova Technologies Reseller API client.
//
package main

import (
	"log"

	"centova.com/resellerapi"
)

func main() {
	username := "username" // your account username at centova.com
	apikey := "secret"     // your reseller API key at centova.com
	testmode := true       // true to use test mode, false to use live mode

	client := resellerapi.NewClient(username, apikey, testmode)

	// Get balance
	if balance, err := client.GetBalance(); err != nil {
		log.Fatalf("Failed to fetch balance: %v\n", err)
	} else {
		log.Printf("Initial balance: USD $%s\n\n", balance.String())
	}

	var orderPackageID int

	// List packages
	if response, err := client.ListPackages(); err != nil {
		log.Fatalf("Failed to fetch packages: %v\n", err)
	} else {
		for _, pkg := range response.Packages {
			log.Printf(
				"#%d - %s: %s monthly, %s quarterly, %s biannually, %s annually, %s setup\n",
				pkg.ID, pkg.Name, pkg.PriceMonthly.String(), pkg.PriceQuarterly.String(), pkg.PriceBiannually.String(),
				pkg.PriceAnnually.String(), pkg.PriceSetup.String(),
			)
		}
		log.Printf("Total of %d package(s)\n\n", len(response.Packages))
		orderPackageID = response.Packages[2].ID
	}

	var orderedLicenseID int

	// Place an order for the third package returned above
	if order, err := client.OrderLicense(
		orderPackageID,
		resellerapi.MonthlyBilling,
		"test.example.com",
		"example@example.com",
		false,
		"mycustomorderid",
		"",
	); err != nil {
		log.Fatalf("Failed to place order: %v\n", err)
	} else {
		log.Printf(
			"Ordered license #%d (invoice #%d). Cost of USD$%s one-time, USD$%s recurring.\n\n",
			order.LicenseID, order.InvoiceID, order.AmountInvoice.String(), order.AmountRecurring.String(),
		)
		orderedLicenseID = order.LicenseID
	}

	// Search for the license we ordered above
	if response, err := client.ListLicensesByID(orderedLicenseID); err != nil {
		log.Fatalf("Failed to list licenses: %v\n", err)
	} else {
		if len(response.Licenses) == 0 {
			log.Fatalf("Did not find license #%d\n", orderedLicenseID)
		}

		license := response.Licenses[0]

		log.Println("Details for the license we just ordered:")

		log.Printf(
			"#%d - %s; %s; for %s %s; created %s, USD $%s %s, next %s\n\n",
			license.ID, license.DisplayName, license.Status, license.LicensedDomain, license.LicensedIP,
			license.CreationDate, license.BillingAmount.String(), license.BillingPeriod, license.BillingNext,
		)
	}

	// Get the new balance
	if balance, err := client.GetBalance(); err != nil {
		log.Fatalf("Failed to fetch balance: %v\n", err)
	} else {
		log.Printf("New balance: USD $%s\n\n", balance.String())
	}

	// List all licenses
	if response, err := client.ListLicenses(); err != nil {
		log.Fatalf("Failed to list licenses: %v\n", err)
	} else {
		if len(response.Licenses) == 0 {
			log.Fatalf("Did not find any licenses\n")
		}

		log.Println("All licenses on this account:")

		for _, license := range response.Licenses {
			log.Printf(
				"#%d - %s; %s; for %s %s; created %s, USD $%s %s, next %s\n",
				license.ID, license.DisplayName, license.Status, license.LicensedDomain, license.LicensedIP,
				license.CreationDate, license.BillingAmount.String(), license.BillingPeriod, license.BillingNext,
			)
		}
		log.Println()
	}

	// Cancel the license we just ordered
	if err := client.CancelLicense(orderedLicenseID); err != nil {
		log.Fatalf("Failed to cancel license %d: %v", orderedLicenseID, err)
	}

	log.Println("Cancelled license")
}
