<?php
/*
 * Centova Reseller API - https://centova.com
 * Copyright 2008-2021, Centova Technologies Inc.
 *
 *****************************************************************************
 *
 * This library is a PHP implementation of a Centova Technologies Reseller API
 * client.
 *
 */

Header('Content-type: text/plain');

register_autoloader(); // install simple PSR-4 autoloader; you'd normally use your own

$username = 'username';		// your account username at centova.com
$api_key = 'secret';		// your reseller API key at centova.com
$testmode = true;			// true to use test mode, false to use live mode

try {
	$api = new Centova\Reseller\APIClient($username,$api_key,$testmode);
	
	/* ****** get balance ****** */
	$balance = $api->getBalance();
	echo 'Initial balance: USD $'.$balance."\n\n";

	/* ****** list packages ****** */
	$packages = $api->listPackages();
	foreach ($packages as $k => $package) {
		echo '#' . $package['package_id'] . ' - ' . $package['package_name'] . ': ' . $package['price_monthly'] . ' monthly, ' . $package['price_quarterly'] . ' quarterly, ' . $package['price_biannually'] . ' biannually, ' . $package['price_annually'] . ' annually, ' . $package['price_setup'] . ' setup' . "\n";
	}
	echo "Total of " . count($packages) . " package(s)\n\n";


	/* ****** place an order for the third package returned above ****** */
	$orderpackage = $packages[2];

	$want_installation = true;				// does the client want us to install this license?
	$period = 'monthly';					// desired billing period
	$client_email = 'example@example.com';	// license details will be E-mailed here when order is processed
	$domain = 'test.example.com';			// domain name for the license
	$customident = 'mycustomorderid';		// any custom ID that you may want to store with the license

	$order = $api->orderLicense($orderpackage['package_id'],$period,$domain,$client_email,$want_installation,$customident);
	echo "Ordered license #".$order['license_id']." (invoice #".$order['invoice_id'].").  Cost of USD$".$order['amount_invoice']." one-time, USD$".$order['amount_recurring']." recurring.\n\n";

	/* ****** search for the license we ordered above ****** */
	$licenses = $api->listLicenses($order['license_id']);

	echo "\nDetails for the license we just ordered:\n";
	$license = $licenses[0];
	echo '#' . $license['license_id'] . ' - ' . $license['display_name'] . '; ' . $license['status'] . '; for ' . $license['licensed_domain'] . ' ' . $license['licensed_ip'] . '; created ' . $license['creation_date'] . ', USD $' . $license['billing_amount'] . ' ' . $license['billing_period'] . '; next ' . $license['billing_next'] . "\n";
	echo "\n";

	
	/* ****** get new balance ****** */
	$balance = $api->getBalance();
	echo 'New balance: USD $'.$balance."\n\n";

	/* ****** list all licenses ****** */
	$licenses = $api->listLicenses();

	echo "\nAll licenses on this account:\n";
	foreach ($licenses as $license) {
		echo '#' . $license['license_id'] . ' - ' . $license['display_name'] . '; ' . $license['status'] . '; for ' . $license['licensed_domain'] . ' ' . $license['licensed_ip'] . '; created ' . $license['creation_date'] . ', USD $' . $license['billing_amount'] . ' ' . $license['billing_period'] . '; next ' . $license['billing_next'] . "\n";
	}
	echo "\n";


	/* ****** cancel the license we just ordered ****** */
	$api->cancelLicense($order['license_id']);
	echo "License cancelled\n\n";


} catch (Centova\Reseller\APIClientArgumentError $e) {
	die('An argument passed to the API client was not valid: ' . $e->getMessage());

} catch (Centova\Reseller\APIClientEnvironmentError $e) {
	die('Environment problem: ' . $e->getMessage());

} catch (Centova\Reseller\APIClientRequestError $e) {
	die('API server could not be reached: '.$e->getMessage());

} catch (Centova\Reseller\APIClientServerError $e) {
	die('API server returned an error: ' . $e->getMessage());

} catch (Centova\Reseller\APIClientException $e) {
	die('An unexpected error occurred: ' . $e->getMessage());
}


function register_autoloader() {
	spl_autoload_register(function ($class) {
	    $prefix = 'Centova\\Reseller\\';
	    $base_dir = __DIR__ . '/Centova/Reseller/';

	    $len = strlen($prefix);
	    if (strncmp($prefix, $class, $len) !== 0) {
	        return;
	    }

	    $relative_class = substr($class, $len);
	    $file = $base_dir . str_replace('\\', '/', $relative_class) . '.php';

	    // if the file exists, require it
	    if (file_exists($file)) {
	        require $file;
	    }
	});
}